/*====================================================================

ObjectWeb Transaction Working Group API
Contact: http://www.objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Romain Rouvoy.
Contributor(s): ______________________________________.

---------------------------------------------------------------------
$Id: DependencyTypeCausal.java,v 1.1.1.1 2003/12/01 15:14:19 rouvoy Exp $
====================================================================*/
package org.objectweb.transaction.lib.transaction;

import org.objectweb.transaction.api.dependency.DependencyType;

/**
 * DependencyType for a causal inter-transactions dependency.</BR>
 * <b>Causal Dependency</b>: This type of dependency should cause a 
 * significant event in case of occurence of another significant event. 
 * The ability to ensure a causal dependency depends on the forcability 
 * of the significant event that should be caused.
 * 
 * @author <a href="mailto:Romain.Rouvoy@lifl.fr">Romain Rouvoy</a>
 * @version 0.1
 */
public class DependencyTypeCausal 
  implements DependencyType 
{
    /** Int value for dependency type <i>Causal</i>. */
    public static final int value = DependencyTypeCausal.class.getName().hashCode();

    /** Object value for the dependency type <i>Causal</i>. */
    public static final DependencyType type = new DependencyTypeCausal();

    /* (non-Javadoc)
     * @see org.objectweb.transaction.api.dependency.DependencyType#getValue()
     */
    public int getValue() {
        return value;
    }

    /* (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    public String toString() {
        return "Causal Transactions Dependency Type" ;
    }
}
